@@ -18,43 +18,36 @@ References
 - `Blog post on redirecting and file descriptors
   <https://eli.thegreenplace.net/2015/redirecting-all-kinds-of-stdout-in-python>`_.
 - `The capture module in pytest
-  <https://github.com/pytest-dev/pytest/blob/master/src/_pytest/capture.py>`_.
+  <https://github.com/pytest-dev/pytest/blob/main/src/_pytest/capture.py>`_.
 - `The debugging module in pytest
-  <https://github.com/pytest-dev/pytest/blob/master/src/_pytest/debugging.py>`_.
+  <https://github.com/pytest-dev/pytest/blob/main/src/_pytest/debugging.py>`_.
 
 """
+from __future__ import annotations
+
 import contextlib
 import functools
 import io
 import os
 import sys
+from enum import Enum
 from tempfile import TemporaryFile
+from typing import Any
 from typing import AnyStr
 from typing import Generator
 from typing import Generic
 from typing import Iterator
-from typing import Optional
 from typing import TextIO
-from typing import Tuple
-from typing import TYPE_CHECKING
-from typing import Union
 
 import click
 from _pytask.config import hookimpl
-from _pytask.nodes import MetaTask
+from _pytask.config_utils import parse_click_choice
+from _pytask.config_utils import ShowCapture
+from _pytask.nodes import Task
 from _pytask.shared import get_first_non_none_value
 
-if TYPE_CHECKING:
-    from typing_extensions import Literal
 
-    _CaptureMethod = Literal["fd", "sys", "no", "tee-sys"]
-
-if TYPE_CHECKING:
-    if sys.version_info >= (3, 8):
-        from typing import final as final
-    else:
-        from typing_extensions import final as final
-elif sys.version_info >= (3, 8):
+if sys.version_info >= (3, 8):
     from typing import final as final
 else:
 
@@ -62,22 +55,33 @@ else:
         return f
 
 
+class _CaptureMethod(Enum):
+    FD = "fd"
+    NO = "no"
+    SYS = "sys"
+    TEE_SYS = "tee-sys"
+
+
 @hookimpl
-def pytask_extend_command_line_interface(cli):
+def pytask_extend_command_line_interface(cli: click.Group) -> None:
     """Add CLI options for capturing output."""
     additional_parameters = [
         click.Option(
             ["--capture"],
-            type=click.Choice(["fd", "no", "sys", "tee-sys"]),
-            help="Per task capturing method.  [default: fd]",
+            type=click.Choice([x.value for x in _CaptureMethod]),
+            help="Per task capturing method. [dim]\\[default: fd][/]",
+        ),
+        click.Option(
+            ["-s"],
+            is_flag=True,
+            help="Shortcut for --capture=no.",
         ),
-        click.Option(["-s"], is_flag=True, help="Shortcut for --capture=no."),
         click.Option(
             ["--show-capture"],
-            type=click.Choice(["no", "stdout", "stderr", "all"]),
+            type=click.Choice([x.value for x in ShowCapture]),
             help=(
-                "Choose which captured output should be shown for failed tasks.  "
-                "[default: all]"
+                "Choose which captured output should be shown for failed tasks. "
+                "[dim]\\[default: all][/]"
             ),
         ),
     ]
@@ -85,39 +89,40 @@ def pytask_extend_command_line_interface(cli):
 
 
 @hookimpl
-def pytask_parse_config(config, config_from_cli, config_from_file):
+def pytask_parse_config(
+    config: dict[str, Any],
+    config_from_cli: dict[str, Any],
+    config_from_file: dict[str, Any],
+) -> None:
     """Parse configuration.
 
     Note that, ``-s`` is a shortcut for ``--capture=no``.
 
     """
     if config_from_cli.get("s"):
-        config["capture"] = "no"
+        config["capture"] = _CaptureMethod.NO
     else:
         config["capture"] = get_first_non_none_value(
             config_from_cli,
             config_from_file,
             key="capture",
-            default="fd",
-            callback=_capture_callback,
+            default=_CaptureMethod.FD,
+            callback=parse_click_choice("capture", _CaptureMethod),
         )
 
     config["show_capture"] = get_first_non_none_value(
         config_from_cli,
         config_from_file,
         key="show_capture",
-        default="all",
-        callback=_show_capture_callback,
+        default=ShowCapture.ALL,
+        callback=parse_click_choice("show_capture", ShowCapture),
     )
 
 
 @hookimpl
-def pytask_post_parse(config):
+def pytask_post_parse(config: dict[str, Any]) -> None:
     """Initialize the CaptureManager."""
-    if config["capture"] == "fd":
-        _py36_windowsconsoleio_workaround(sys.stdout)
     _colorama_workaround()
-    _readline_workaround()
 
     pluginmanager = config["pm"]
     capman = CaptureManager(config["capture"])
@@ -127,32 +132,6 @@ def pytask_post_parse(config):
     capman.suspend()
 
 
-def _capture_callback(x):
-    """Validate the passed options for capturing output."""
-    if x in [None, "None", "none"]:
-        x = None
-    elif x in ["fd", "no", "sys", "tee-sys"]:
-        pass
-    else:
-        raise ValueError("'capture' can only be one of ['fd', 'no', 'sys', 'tee-sys'].")
-
-    return x
-
-
-def _show_capture_callback(x):
-    """Validate the passed options for showing captured output."""
-    if x in [None, "None", "none"]:
-        x = None
-    elif x in ["no", "stdout", "stderr", "all"]:
-        pass
-    else:
-        raise ValueError(
-            "'show_capture' must be one of ['no', 'stdout', 'stderr', 'all']."
-        )
-
-    return x
-
-
 # Copied from pytest with slightly modified docstrings.
 
 
@@ -172,88 +151,6 @@ def _colorama_workaround() -> None:
             pass
 
 
-def _readline_workaround() -> None:
-    """Ensure readline is imported so that it attaches to the correct stdio handles on
-    Windows.
-
-    Pdb uses readline support where available -- when not running from the Python
-    prompt, the readline module is not imported until running the pdb REPL.  If running
-    pytest with the ``--pdb`` option this means the readline module is not imported
-    until after I/O capture has been started.
-
-    This is a problem for pyreadline, which is often used to implement readline support
-    on Windows, as it does not attach to the correct handles for stdout and/or stdin if
-    they have been redirected by the FDCapture mechanism.  This workaround ensures that
-    readline is imported before I/O capture is setup so that it can attach to the actual
-    stdin/out for the console.
-
-    See https://github.com/pytest-dev/pytest/pull/1281.
-
-    """
-    if sys.platform.startswith("win32"):
-        try:
-            import readline  # noqa: F401
-        except ImportError:
-            pass
-
-
-def _py36_windowsconsoleio_workaround(stream: TextIO) -> None:
-    """Workaround for Windows Unicode console handling on Python>=3.6.
-
-    Python 3.6 implemented Unicode console handling for Windows. This works by
-    reading/writing to the raw console handle using ``{Read,Write}ConsoleW``.
-
-    The problem is that we are going to ``dup2`` over the stdio file descriptors when
-    doing ``FDCapture`` and this will ``CloseHandle`` the handles used by Python to
-    write to the console. Though there is still some weirdness and the console handle
-    seems to only be closed randomly and not on the first call to ``CloseHandle``, or
-    maybe it gets reopened with the same handle value when we suspend capturing.
-
-    The workaround in this case will reopen stdio with a different fd which also means a
-    different handle by replicating the logic in
-    "Py_lifecycle.c:initstdio/create_stdio".
-
-    Parameters
-    ---------
-    stream
-        In practice ``sys.stdout`` or ``sys.stderr``, but given here as parameter for
-        unit testing purposes.
-
-    See https://github.com/pytest-dev/py/issues/103.
-
-    """
-    if not sys.platform.startswith("win32") or hasattr(sys, "pypy_version_info"):
-        return
-
-    # Bail out if ``stream`` doesn't seem like a proper ``io`` stream (#2666).
-    if not hasattr(stream, "buffer"):  # type: ignore[unreachable]
-        return
-
-    buffered = hasattr(stream.buffer, "raw")
-    raw_stdout = stream.buffer.raw if buffered else stream.buffer
-
-    if not isinstance(raw_stdout, io._WindowsConsoleIO):  # type: ignore[attr-defined]
-        return
-
-    def _reopen_stdio(f, mode):
-        if not buffered and mode[0] == "w":
-            buffering = 0
-        else:
-            buffering = -1
-
-        return io.TextIOWrapper(
-            open(os.dup(f.fileno()), mode, buffering),  # type: ignore[arg-type]
-            f.encoding,
-            f.errors,
-            f.newlines,
-            f.line_buffering,
-        )
-
-    sys.stdin = _reopen_stdio(sys.stdin, "rb")
-    sys.stdout = _reopen_stdio(sys.stdout, "wb")
-    sys.stderr = _reopen_stdio(sys.stderr, "wb")
-
-
 # IO Helpers.
 
 
@@ -296,16 +193,16 @@ class DontReadFromInput:
 
     encoding = None
 
-    def read(self, *_args):  # noqa: U101
+    def read(self, *_args: Any) -> None:  # noqa: U101
         raise OSError(
-            "pytest: reading from stdin while output is captured! Consider using `-s`."
+            "pytask: reading from stdin while output is captured! Consider using `-s`."
         )
 
     readline = read
     readlines = read
     __next__ = read
 
-    def __iter__(self):
+    def __iter__(self) -> DontReadFromInput:
         return self
 
     def fileno(self) -> int:
@@ -318,7 +215,7 @@ class DontReadFromInput:
         pass
 
     @property
-    def buffer(self):
+    def buffer(self) -> DontReadFromInput:
         return self
 
 
@@ -345,7 +242,13 @@ class SysCaptureBinary:
 
     EMPTY_BUFFER = b""
 
-    def __init__(self, fd: int, tmpfile=None, *, tee: bool = False) -> None:
+    def __init__(  # type: ignore
+        self,
+        fd: int,
+        tmpfile=None,
+        *,
+        tee: bool = False,
+    ) -> None:
         name = patchsysdict[fd]
         self._old = getattr(sys, name)
         self.name = name
@@ -375,7 +278,7 @@ class SysCaptureBinary:
             self.tmpfile,
         )
 
-    def _assert_state(self, op: str, states: Tuple[str, ...]) -> None:
+    def _assert_state(self, op: str, states: tuple[str, ...]) -> None:
         assert (
             self._state in states
         ), "cannot {} in state {!r}: expected one of {}".format(
@@ -387,7 +290,7 @@ class SysCaptureBinary:
         setattr(sys, self.name, self.tmpfile)
         self._state = "started"
 
-    def snap(self):
+    def snap(self) -> str:
         self._assert_state("snap", ("started", "suspended"))
         self.tmpfile.seek(0)
         res = self.tmpfile.buffer.read()
@@ -416,7 +319,7 @@ class SysCaptureBinary:
         setattr(sys, self.name, self.tmpfile)
         self._state = "started"
 
-    def writeorg(self, data) -> None:
+    def writeorg(self, data: str) -> None:
         self._assert_state("writeorg", ("started", "suspended"))
         self._old.flush()
         self._old.buffer.write(data)
@@ -432,13 +335,13 @@ class SysCapture(SysCaptureBinary):
 
     EMPTY_BUFFER = ""  # type: ignore[assignment]
 
-    def snap(self):
+    def snap(self) -> str:
         res = self.tmpfile.getvalue()
         self.tmpfile.seek(0)
         self.tmpfile.truncate()
         return res
 
-    def writeorg(self, data):
+    def writeorg(self, data: str) -> None:
         self._assert_state("writeorg", ("started", "suspended"))
         self._old.write(data)
         self._old.flush()
@@ -470,7 +373,7 @@ class FDCaptureBinary:
             # Further complications are the need to support suspend() and the
             # possibility of FD reuse (e.g. the tmpfile getting the very same target
             # FD). The following approach is robust, I believe.
-            self.targetfd_invalid: Optional[int] = os.open(os.devnull, os.O_RDWR)
+            self.targetfd_invalid: int | None = os.open(os.devnull, os.O_RDWR)
             os.dup2(self.targetfd_invalid, targetfd)
         else:
             self.targetfd_invalid = None
@@ -481,7 +384,7 @@ class FDCaptureBinary:
             self.syscapture = SysCapture(targetfd)
         else:
             self.tmpfile = EncodedFile(
-                TemporaryFile(buffering=0),  # type: ignore[arg-type]
+                TemporaryFile(buffering=0),
                 encoding="utf-8",
                 errors="replace",
                 newline="",
@@ -503,7 +406,7 @@ class FDCaptureBinary:
             self.tmpfile,
         )
 
-    def _assert_state(self, op: str, states: Tuple[str, ...]) -> None:
+    def _assert_state(self, op: str, states: tuple[str, ...]) -> None:
         assert (
             self._state in states
         ), "cannot {} in state {!r}: expected one of {}".format(
@@ -517,7 +420,7 @@ class FDCaptureBinary:
         self.syscapture.start()
         self._state = "started"
 
-    def snap(self):
+    def snap(self) -> bytes:
         self._assert_state("snap", ("started", "suspended"))
         self.tmpfile.seek(0)
         res = self.tmpfile.buffer.read()
@@ -557,7 +460,7 @@ class FDCaptureBinary:
         os.dup2(self.tmpfile.fileno(), self.targetfd)
         self._state = "started"
 
-    def writeorg(self, data):
+    def writeorg(self, data: bytes) -> None:
         """Write to original file descriptor."""
         self._assert_state("writeorg", ("started", "suspended"))
         os.write(self.targetfd_save, data)
@@ -573,7 +476,8 @@ class FDCapture(FDCaptureBinary):
     # Ignore type because it doesn't match the type in the superclass (bytes).
     EMPTY_BUFFER = ""  # type: ignore
 
-    def snap(self):
+    # Ignore type because it doesn't match the type in the superclass (bytes).
+    def snap(self) -> str:  # type: ignore
         self._assert_state("snap", ("started", "suspended"))
         self.tmpfile.seek(0)
         res = self.tmpfile.read()
@@ -581,7 +485,8 @@ class FDCapture(FDCaptureBinary):
         self.tmpfile.truncate()
         return res
 
-    def writeorg(self, data):
+    # Ignore type because it doesn't match the type in the superclass (bytes).
+    def writeorg(self, data: str) -> None:  # type: ignore
         """Write to original file descriptor."""
         super().writeorg(data.encode("utf-8"))
 
@@ -603,9 +508,7 @@ class CaptureResult(Generic[AnyStr]):
 
     """
 
-    # Can't use slots in Python<3.5.3 due to https://bugs.python.org/issue31272
-    if sys.version_info >= (3, 5, 3):
-        __slots__ = ("out", "err")
+    __slots__ = ("out", "err")
 
     def __init__(self, out: AnyStr, err: AnyStr) -> None:
         self.out: AnyStr = out
@@ -621,8 +524,8 @@ class CaptureResult(Generic[AnyStr]):
         return tuple(self)[item]
 
     def _replace(
-        self, *, out: Optional[AnyStr] = None, err: Optional[AnyStr] = None
-    ) -> "CaptureResult[AnyStr]":
+        self, *, out: AnyStr | None = None, err: AnyStr | None = None
+    ) -> CaptureResult[AnyStr]:
         return CaptureResult(
             out=self.out if out is None else out, err=self.err if err is None else err
         )
@@ -630,7 +533,7 @@ class CaptureResult(Generic[AnyStr]):
     def count(self, value: AnyStr) -> int:
         return tuple(self).count(value)
 
-    def index(self, value) -> int:
+    def index(self, value: int) -> int:
         return tuple(self).index(value)
 
     def __eq__(self, other: object) -> bool:
@@ -662,7 +565,12 @@ class MultiCapture(Generic[AnyStr]):
     _state = None
     _in_suspended = False
 
-    def __init__(self, in_, out, err) -> None:
+    def __init__(
+        self,
+        in_: FDCapture | SysCapture | None,
+        out: FDCapture | SysCapture | None,
+        err: FDCapture | SysCapture | None,
+    ) -> None:
         self.in_ = in_
         self.out = out
         self.err = err
@@ -688,13 +596,13 @@ class MultiCapture(Generic[AnyStr]):
         if self.err:
             self.err.start()
 
-    def pop_outerr_to_orig(self) -> Tuple[AnyStr, AnyStr]:
+    def pop_outerr_to_orig(self) -> tuple[AnyStr, AnyStr]:
         """Pop current snapshot out/err capture and flush to orig streams."""
         out, err = self.readouterr()
         if out:
-            self.out.writeorg(out)
+            self.out.writeorg(out)  # type: ignore
         if err:
-            self.err.writeorg(err)
+            self.err.writeorg(err)  # type: ignore
         return out, err
 
     def suspend_capturing(self, in_: bool = False) -> None:
@@ -742,23 +650,23 @@ class MultiCapture(Generic[AnyStr]):
             err = self.err.snap()
         else:
             err = ""
-        return CaptureResult(out, err)
+        return CaptureResult(out, err)  # type: ignore
 
 
-def _get_multicapture(method: "_CaptureMethod") -> MultiCapture[str]:
+def _get_multicapture(method: _CaptureMethod) -> MultiCapture[str]:
     """Set up the MultiCapture class with the passed method.
 
     For each valid method, the function instantiates the :class:`MultiCapture` class
     with the specified buffers for ``stdin``, ``stdout``, and ``stderr``.
 
     """
-    if method == "fd":
+    if method == _CaptureMethod.FD:
         return MultiCapture(in_=FDCapture(0), out=FDCapture(1), err=FDCapture(2))
-    elif method == "sys":
+    elif method == _CaptureMethod.SYS:
         return MultiCapture(in_=SysCapture(0), out=SysCapture(1), err=SysCapture(2))
-    elif method == "no":
+    elif method == _CaptureMethod.NO:
         return MultiCapture(in_=None, out=None, err=None)
-    elif method == "tee-sys":
+    elif method == _CaptureMethod.TEE_SYS:
         return MultiCapture(
             in_=None, out=SysCapture(1, tee=True), err=SysCapture(2, tee=True)
         )
@@ -781,16 +689,16 @@ class CaptureManager:
 
     """
 
-    def __init__(self, method: "_CaptureMethod") -> None:
+    def __init__(self, method: _CaptureMethod) -> None:
         self._method = method
-        self._capturing: Optional[MultiCapture[str]] = None
+        self._capturing: MultiCapture[str] | None = None
 
     def __repr__(self) -> str:
         return ("<CaptureManager _method={!r} _capturing={!r}>").format(
             self._method, self._capturing
         )
 
-    def is_capturing(self) -> Union[str, bool]:
+    def is_capturing(self) -> bool:
         return self._method != "no"
 
     def start_capturing(self) -> None:
@@ -821,7 +729,7 @@ class CaptureManager:
     # Helper context managers
 
     @contextlib.contextmanager
-    def task_capture(self, when: str, task: MetaTask) -> Generator[None, None, None]:
+    def task_capture(self, when: str, task: Task) -> Generator[None, None, None]:
         """Pipe captured stdout and stderr into report sections."""
         self.resume()
 
@@ -837,21 +745,34 @@ class CaptureManager:
     # Hooks
 
     @hookimpl(hookwrapper=True)
-    def pytask_execute_task_setup(self, task: MetaTask) -> Generator[None, None, None]:
+    def pytask_execute_task_setup(self, task: Task) -> Generator[None, None, None]:
         """Capture output during setup."""
         with self.task_capture("setup", task):
             yield
 
     @hookimpl(hookwrapper=True)
-    def pytask_execute_task(self, task: MetaTask) -> Generator[None, None, None]:
+    def pytask_execute_task(self, task: Task) -> Generator[None, None, None]:
         """Capture output during execution."""
         with self.task_capture("call", task):
             yield
 
     @hookimpl(hookwrapper=True)
-    def pytask_execute_task_teardown(
-        self, task: MetaTask
-    ) -> Generator[None, None, None]:
+    def pytask_execute_task_teardown(self, task: Task) -> Generator[None, None, None]:
         """Capture output during teardown."""
         with self.task_capture("teardown", task):
             yield
+
+    @hookimpl(hookwrapper=True)
+    def pytask_collect_log(self) -> Generator[None, None, None]:
+        """Suspend capturing at the end of the collection.
+
+        This hook needs to be here as long as the collection has no proper capturing. If
+        ``pdb.set_trace`` stops the collection, continuation in ``do_continue`` enables
+        the capture manager. Then, the collection status will be captured and displayed
+        in the output of the first task.
+
+        Here, we stop the capture manager before logging the final collection status.
+
+        """
+        self.suspend(in_=True)
+        yield
