@@ -1,24 +1,20 @@
 """This module contains everything related to debugging."""
+from __future__ import annotations
+
 import functools
 import pdb
 import sys
 from types import FrameType
 from types import TracebackType
 from typing import Any
-from typing import Dict
 from typing import Generator
-from typing import List
-from typing import Optional
-from typing import Tuple
-from typing import Type
 from typing import TYPE_CHECKING
 
 import click
 import pluggy
 from _pytask.config import hookimpl
 from _pytask.console import console
-from _pytask.nodes import MetaTask
-from _pytask.nodes import PythonFunctionTask
+from _pytask.nodes import Task
 from _pytask.outcomes import Exit
 from _pytask.session import Session
 from _pytask.shared import convert_truthy_or_falsy_to_bool
@@ -38,13 +34,15 @@ def pytask_extend_command_line_interface(cli: click.Group) -> None:
     additional_parameters = [
         click.Option(
             ["--pdb"],
-            help="Start the interactive debugger on errors.  [default: False]",
+            help="Start the interactive debugger on errors.  "
+            "[dim]\\[default: False][/]",
             is_flag=True,
             default=None,
         ),
         click.Option(
             ["--trace"],
-            help="Enter debugger in the beginning of each task.  [default: False]",
+            help="Enter debugger in the beginning of each task.  "
+            "[dim]\\[default: False][/]",
             is_flag=True,
             default=None,
         ),
@@ -62,21 +60,19 @@ def pytask_extend_command_line_interface(cli: click.Group) -> None:
 
 @hookimpl
 def pytask_parse_config(
-    config: Dict[str, Any],
-    config_from_cli: Dict[str, Any],
-    config_from_file: Dict[str, Any],
+    config: dict[str, Any],
+    config_from_cli: dict[str, Any],
+    config_from_file: dict[str, Any],
 ) -> None:
     """Parse the configuration."""
     config["pdb"] = get_first_non_none_value(
         config_from_cli,
-        config_from_file,
         key="pdb",
         default=False,
         callback=convert_truthy_or_falsy_to_bool,
     )
     config["trace"] = get_first_non_none_value(
         config_from_cli,
-        config_from_file,
         key="trace",
         default=False,
         callback=convert_truthy_or_falsy_to_bool,
@@ -97,7 +93,7 @@ def pytask_parse_config(
     )
 
 
-def _pdbcls_callback(x: Optional[str]) -> Optional[Tuple[str, str]]:
+def _pdbcls_callback(x: str | None) -> tuple[str, str] | None:
     """Validate the debugger class string passed to pdbcls."""
     message = "'pdbcls' must be like IPython.terminal.debugger:TerminalPdb"
 
@@ -114,7 +110,7 @@ def _pdbcls_callback(x: Optional[str]) -> Optional[Tuple[str, str]]:
 
 
 @hookimpl(trylast=True)
-def pytask_post_parse(config: Dict[str, Any]) -> None:
+def pytask_post_parse(config: dict[str, Any]) -> None:
     """Post parse the configuration.
 
     Register the plugins in this step to let other plugins influence the pdb or trace
@@ -149,22 +145,24 @@ def pytask_unconfigure() -> None:
 class PytaskPDB:
     """Pseudo PDB that defers to the real pdb."""
 
-    _pluginmanager: Optional[pluggy.PluginManager] = None
-    _config: Optional[Dict[str, Any]] = None
-    _saved: List[Tuple[Any, ...]] = []
+    _pluginmanager: pluggy.PluginManager | None = None
+    _config: dict[str, Any] | None = None
+    _saved: list[tuple[Any, ...]] = []
     _recursive_debug: int = 0
-    _wrapped_pdb_cls: Optional[Tuple[Type[pdb.Pdb], Type[pdb.Pdb]]] = None
+    _wrapped_pdb_cls: tuple[type[pdb.Pdb], type[pdb.Pdb]] | None = None
 
     @classmethod
-    def _is_capturing(cls, capman: "CaptureManager") -> bool:
+    def _is_capturing(cls, capman: CaptureManager) -> bool:
+        """Check if the capture manager is capturing."""
         if capman:
             return capman.is_capturing()
         return False
 
     @classmethod
     def _import_pdb_cls(
-        cls, capman: "CaptureManager", live_manager: "LiveManager"
-    ) -> Type[pdb.Pdb]:
+        cls, capman: CaptureManager, live_manager: LiveManager
+    ) -> type[pdb.Pdb]:
+        """Create a debugger from an imported class."""
         if not cls._config:
             import pdb
 
@@ -204,11 +202,9 @@ class PytaskPDB:
 
     @classmethod
     def _get_pdb_wrapper_class(
-        cls,
-        pdb_cls: Type[pdb.Pdb],
-        capman: "CaptureManager",
-        live_manager: "LiveManager",
-    ) -> Type[pdb.Pdb]:
+        cls, pdb_cls: type[pdb.Pdb], capman: CaptureManager, live_manager: LiveManager
+    ) -> type[pdb.Pdb]:
+        """Create a pdf wrapper class."""
         # Type ignored because mypy doesn't support "dynamic"
         # inheritance like this.
         class PytaskPdbWrapper(pdb_cls):  # type: ignore[valid-type,misc]
@@ -284,7 +280,7 @@ class PytaskPDB:
                         self._pytask_live_manager.pause()
                 return ret
 
-            def get_stack(self, f: FrameType, t: TracebackType) -> Tuple[str, int]:
+            def get_stack(self, f: FrameType, t: TracebackType) -> tuple[str, int]:
                 stack, i = super().get_stack(f, t)
                 if f is None:
                     # Find last non-hidden frame.
@@ -346,15 +342,15 @@ class PdbDebugger:
     @staticmethod
     @hookimpl(hookwrapper=True)
     def pytask_execute_task(
-        session: Session, task: MetaTask
+        session: Session, task: Task
     ) -> Generator[None, None, None]:
         """Execute a task by wrapping the function with post-mortem debugger."""
-        if isinstance(task, PythonFunctionTask):
+        if isinstance(task, Task):
             wrap_function_for_post_mortem_debugging(session, task)
         yield
 
 
-def wrap_function_for_post_mortem_debugging(session: Session, task: MetaTask) -> None:
+def wrap_function_for_post_mortem_debugging(session: Session, task: Task) -> None:
     """Wrap the function for post-mortem debugging."""
 
     task_function = task.function
@@ -407,15 +403,15 @@ class PdbTrace:
     @staticmethod
     @hookimpl(hookwrapper=True)
     def pytask_execute_task(
-        session: Session, task: MetaTask
+        session: Session, task: Task
     ) -> Generator[None, None, None]:
         """Wrapping the task function with a tracer."""
-        if isinstance(task, PythonFunctionTask):
+        if isinstance(task, Task):
             wrap_function_for_tracing(session, task)
         yield
 
 
-def wrap_function_for_tracing(session: Session, task: MetaTask) -> None:
+def wrap_function_for_tracing(session: Session, task: Task) -> None:
     """Wrap the task function for tracing."""
 
     _pdb = PytaskPDB._init_pdb("runcall")
