@@ -1,14 +1,11 @@
 """Add general logging capabilities."""
+from __future__ import annotations
+
 import platform
 import sys
 import warnings
 from typing import Any
-from typing import Dict
-from typing import List
-from typing import Optional
-from typing import Tuple
-from typing import TYPE_CHECKING
-from typing import Union
+from typing import NamedTuple
 
 import _pytask
 import click
@@ -30,21 +27,11 @@ except ImportError:
     from pluggy.manager import DistFacade
 
 
-if TYPE_CHECKING and sys.version_info >= (3, 8):
-    from typing import TypedDict
-
-    class _TimeUnit(TypedDict):
-        singular: str
-        plural: str
-        short: str
-        in_seconds: int
-
-    if sys.version_info >= (3, 8):
-        from typing import Literal
-    else:
-        from typing_extensions import Literal
-
-    _ShowTraceback = Literal["no", "yes"]
+class _TimeUnit(NamedTuple):
+    singular: str
+    plural: str
+    short: str
+    in_seconds: int
 
 
 @hookimpl
@@ -60,9 +47,9 @@ def pytask_extend_command_line_interface(cli: click.Group) -> None:
 
 @hookimpl
 def pytask_parse_config(
-    config: Dict[str, Any],
-    config_from_file: Dict[str, Any],
-    config_from_cli: Dict[str, Any],
+    config: dict[str, Any],
+    config_from_file: dict[str, Any],
+    config_from_cli: dict[str, Any],
 ) -> None:
     """Parse configuration."""
     config["show_locals"] = get_first_non_none_value(
@@ -90,24 +77,11 @@ def pytask_parse_config(
         config_from_cli,
         config_from_file,
         key="show_traceback",
-        default="yes",
-        callback=_show_traceback_callback,
+        default=True,
+        callback=convert_truthy_or_falsy_to_bool,
     )
 
 
-def _show_traceback_callback(
-    x: Optional["_ShowTraceback"],
-) -> Optional["_ShowTraceback"]:
-    """Validate the passed options for showing tracebacks."""
-    if x in [None, "None", "none"]:
-        x = None
-    elif x in ["no", "yes"]:
-        pass
-    else:
-        raise ValueError("'show_traceback' can only be one of ['no', 'yes'].")
-    return x
-
-
 @hookimpl
 def pytask_log_session_header(session: Session) -> None:
     """Log the header of a pytask session."""
@@ -129,10 +103,10 @@ def pytask_log_session_header(session: Session) -> None:
 
 
 def _format_plugin_names_and_versions(
-    plugininfo: List[Tuple[str, DistFacade]]
-) -> List[str]:
+    plugininfo: list[tuple[str, DistFacade]]
+) -> list[str]:
     """Format name and version of loaded plugins."""
-    values: List[str] = []
+    values: list[str] = []
     for _, dist in plugininfo:
         # Gets us name and version!
         name = f"{dist.project_name}-{dist.version}"
@@ -148,7 +122,7 @@ def _format_plugin_names_and_versions(
 @hookimpl
 def pytask_log_session_footer(
     duration: float,
-    outcome: Union[CollectionOutcome, TaskOutcome],
+    outcome: CollectionOutcome | TaskOutcome,
 ) -> None:
     """Format the footer of the log message."""
     formatted_duration = _format_duration(duration)
@@ -158,11 +132,11 @@ def pytask_log_session_footer(
     console.rule(message, style=outcome.style)
 
 
-_TIME_UNITS: List["_TimeUnit"] = [
-    {"singular": "day", "plural": "days", "short": "d", "in_seconds": 86400},
-    {"singular": "hour", "plural": "hours", "short": "h", "in_seconds": 3600},
-    {"singular": "minute", "plural": "minutes", "short": "m", "in_seconds": 60},
-    {"singular": "second", "plural": "seconds", "short": "s", "in_seconds": 1},
+_TIME_UNITS: list[_TimeUnit] = [
+    _TimeUnit(singular="day", plural="days", short="d", in_seconds=86400),
+    _TimeUnit(singular="hour", plural="hours", short="h", in_seconds=3600),
+    _TimeUnit(singular="minute", plural="minutes", short="m", in_seconds=60),
+    _TimeUnit(singular="second", plural="seconds", short="s", in_seconds=1),
 ]
 
 
@@ -181,8 +155,8 @@ def _format_duration(duration: float) -> str:
 
 
 def _humanize_time(
-    amount: Union[int, float], unit: str, short_label: bool = False
-) -> List[Tuple[float, str]]:
+    amount: int | float, unit: str, short_label: bool = False
+) -> list[tuple[float, str]]:
     """Humanize the time.
 
     Examples
@@ -202,44 +176,45 @@ def _humanize_time(
 
     """
     index = None
-    for i, entry in enumerate(_TIME_UNITS):
-        if unit in [entry["singular"], entry["plural"]]:
+    for i, time_unit in enumerate(_TIME_UNITS):
+        if unit in [time_unit.singular, time_unit.plural]:
             index = i
             break
     else:
         raise ValueError(f"The time unit {unit!r} is not known.")
 
-    seconds = amount * _TIME_UNITS[index]["in_seconds"]
-    result: List[Tuple[float, str]] = []
+    seconds = amount * _TIME_UNITS[index].in_seconds
+    result: list[tuple[float, str]] = []
     remaining_seconds = seconds
-    for entry in _TIME_UNITS:
-        whole_units = int(remaining_seconds / entry["in_seconds"])
 
-        if entry["singular"] == "second" and remaining_seconds:
+    for time_unit in _TIME_UNITS:
+        whole_units = int(remaining_seconds / time_unit.in_seconds)
+
+        if time_unit.singular == "second" and remaining_seconds:
             last_seconds = round(remaining_seconds, 2)
             if short_label:
-                label = entry["short"]
+                label = time_unit.short
             elif last_seconds == 1:
-                label = entry["singular"]
+                label = time_unit.singular
             else:
-                label = entry["plural"]
+                label = time_unit.plural
             result.append((last_seconds, label))
 
         elif whole_units >= 1:
-            if entry["singular"] != "seconds":
+            if time_unit.singular != "seconds":
                 if short_label:
-                    label = entry["short"]
+                    label = time_unit.short
                 elif whole_units == 1:
-                    label = entry["singular"]
+                    label = time_unit.singular
                 else:
-                    label = entry["plural"]
+                    label = time_unit.plural
 
                 result.append((whole_units, label))
-                remaining_seconds -= whole_units * entry["in_seconds"]
+                remaining_seconds -= whole_units * time_unit.in_seconds
 
     if not result:
         result.append(
-            (0, _TIME_UNITS[-1]["short"] if short_label else _TIME_UNITS[-1]["plural"])
+            (0, _TIME_UNITS[-1].short if short_label else _TIME_UNITS[-1].plural)
         )
 
     return result
