@@ -7,6 +7,7 @@ from typing import Iterable
 from typing import Mapping
 
 import attr
+from _pytask.models import CollectionMetadata
 
 
 def is_task_function(func: Any) -> bool:
@@ -15,6 +16,8 @@ def is_task_function(func: Any) -> bool:
 
 @attr.s(frozen=True, auto_attribs=True)
 class Mark:
+    """A class for a mark containing the name, positional and keyword arguments."""
+
     name: str
     """str: Name of the mark."""
     args: tuple[Any, ...]
@@ -39,19 +42,14 @@ class Mark:
 
         """
         assert self.name == other.name
-
-        return Mark(
-            self.name,
-            self.args + other.args,
-            {**self.kwargs, **other.kwargs},
-        )
+        return Mark(self.name, self.args + other.args, {**self.kwargs, **other.kwargs})
 
 
 @attr.s
 class MarkDecorator:
     """A decorator for applying a mark on task function.
 
-    MarkDecorators are created with ``pytask.mark``
+    Decorators are created with :class:`pytask.mark`.
 
     .. code-block:: python
 
@@ -66,19 +64,20 @@ class MarkDecorator:
         def task_function():
             pass
 
-    When a MarkDecorator is called it does the following:
+    When a :class:`MarkDecorator` is called it does the following:
 
     1. If called with a single function as its only positional argument and no
        additional keyword arguments, it attaches the mark to the function, containing
-       all the arguments already stored internally in the MarkDecorator.
-    2. When called in any other case, it returns a new MarkDecorator instance with the
-       original MarkDecorator's content updated with the arguments passed to this call.
+       all the arguments already stored internally in the :class:`MarkDecorator`.
+    2. When called in any other case, it returns a new :class:`MarkDecorator` instance
+       with the original :class:`MarkDecorator`'s content updated with the arguments
+       passed to this call.
 
     Notes
     -----
-    The rules above prevent MarkDecorators from storing only a single function or class
+    The rules above prevent decorators from storing only a single function or class
     reference as their positional argument with no additional keyword or positional
-    arguments. You can work around this by using `with_args()`.
+    arguments. You can work around this by using :meth:`MarkDecorator.with_args()`.
 
     """
 
@@ -124,9 +123,10 @@ class MarkDecorator:
 
 def get_unpacked_marks(obj: Callable[..., Any]) -> list[Mark]:
     """Obtain the unpacked marks that are stored on an object."""
-    mark_list = getattr(obj, "pytaskmark", [])
-    if not isinstance(mark_list, list):
-        mark_list = [mark_list]
+    if hasattr(obj, "pytask_meta"):
+        mark_list = obj.pytask_meta.markers  # type: ignore[attr-defined]
+    else:
+        mark_list = []
     return normalize_mark_list(mark_list)
 
 
@@ -156,13 +156,18 @@ def store_mark(obj: Callable[..., Any], mark: Mark) -> None:
 
     """
     assert isinstance(mark, Mark), mark
-    # Always reassign name to avoid updating pytaskmark in a reference that was only
-    # borrowed.
-    obj.pytaskmark = get_unpacked_marks(obj) + [mark]  # type: ignore[attr-defined]
+    if hasattr(obj, "pytask_meta"):
+        obj.pytask_meta.markers = get_unpacked_marks(  # type: ignore[attr-defined]
+            obj
+        ) + [mark]
+    else:
+        obj.pytask_meta = CollectionMetadata(  # type: ignore[attr-defined]
+            markers=[mark]
+        )
 
 
 class MarkGenerator:
-    """Factory for :class:`MarkDecorator` objects - exposed as a ``pytask.mark``
+    """Factory for :class:`MarkDecorator` objects - exposed as a :class:`pytask.mark`
     singleton instance.
 
     Example
@@ -179,23 +184,15 @@ class MarkGenerator:
 
     config: dict[str, Any] | None = None
     """Optional[Dict[str, Any]]: The configuration."""
-    markers: set[str] = set()
-    """Set[str]: The set of markers."""
 
-    def __getattr__(self, name: str) -> MarkDecorator:
+    def __getattr__(self, name: str) -> MarkDecorator | Any:
         if name[0] == "_":
             raise AttributeError("Marker name must NOT start with underscore")
 
         if self.config is not None:
-            # We store a set of markers as a performance optimization - if a mark
-            # name is in the set we definitely know it, but a mark may be known and
-            # not in the set.  We therefore start by updating the set!
-            if name not in self.markers:
-                self.markers.update(self.config["markers"])
-
             # If the name is not in the set of known marks after updating,
             # then it really is time to issue a warning or an error.
-            if name not in self.markers:
+            if name not in self.config["markers"]:
                 if self.config["strict_markers"]:
                     raise ValueError(f"Unknown pytask.mark.{name}.")
                 # Raise a specific error for common misspellings of "parametrize".
@@ -208,6 +205,11 @@ class MarkGenerator:
                     stacklevel=2,
                 )
 
+        if name == "task":
+            from _pytask.task_utils import task
+
+            return task
+
         return MarkDecorator(Mark(name, (), {}))
 
 
